@@ -27,7 +27,7 @@
 #   Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 #   Boston, MA 02111-1307, USA.
 #
-#   $Id: TrueType.pm,v 1.14 2005/10/01 22:30:16 fredo Exp $
+#   $Id: TrueType.pm,v 1.15 2005/10/20 21:04:57 fredo Exp $
 #
 #=======================================================================
 package PDF::API2::Resource::CIDFont::TrueType;
@@ -51,7 +51,7 @@ BEGIN {
 
     @ISA = qw( PDF::API2::Resource::CIDFont );
 
-    ( $VERSION ) = sprintf '%i.%03i', split(/\./,('$Revision: 1.14 $' =~ /Revision: (\S+)\s/)[0]); # $Date: 2005/10/01 22:30:16 $
+    ( $VERSION ) = sprintf '%i.%03i', split(/\./,('$Revision: 1.15 $' =~ /Revision: (\S+)\s/)[0]); # $Date: 2005/10/20 21:04:57 $
 
 }
 no warnings qw[ deprecated recursion uninitialized ];
@@ -107,6 +107,8 @@ sub new {
     $self->{' ff'} = $ff;
     $pdf->new_obj($ff);
 
+    $self->{-dokern}=1 if($opts{-dokern});
+
     return($self);
 }
 
@@ -121,7 +123,8 @@ it needs an PDF::API2-object rather than a Text::PDF::File-object.
 
 =cut
 
-sub new_api {
+sub new_api 
+{
     my ($class,$api,@opts)=@_;
 
     my $obj=$class->new($api->{pdf},@opts);
@@ -131,27 +134,45 @@ sub new_api {
     return($obj);
 }
 
-sub wxByCId {
+sub wxByCId 
+{
     my $self=shift @_;
     my $g=shift @_;
     my $w;
 
-    if(defined $self->fontobj->{'hmtx'}->read->{'advance'}[$g]) {
+    if(defined $self->fontobj->{'hmtx'}->read->{'advance'}[$g]) 
+    {
         $w = int($self->fontobj->{'hmtx'}->read->{'advance'}[$g]*1000/$self->data->{upem});
-    } else {
+    } 
+    else 
+    {
         $w = $self->missingwidth;
     }
 
     return($w);
 }
 
-sub subsetByCId {
+sub haveKernPairs 
+{
+    my $self = shift @_;
+    return($self->fontfile->haveKernPairs(@_));
+}
+
+sub kernPairCid
+{
+    my $self = shift @_;
+    return($self->fontfile->kernPairCid(@_));
+}
+
+sub subsetByCId 
+{
     my $self = shift @_;
     return if($self->iscff);
     my $g = shift @_;
     $self->fontfile->subsetByCId($g);
 }
-sub subvec {
+sub subvec 
+{
     my $self = shift @_;
     return(1) if($self->iscff);
     my $g = shift @_;
@@ -160,7 +181,8 @@ sub subvec {
 
 sub glyphNum { return ( $_[0]->fontfile->glyphNum ); }
 
-sub outobjdeep {
+sub outobjdeep 
+{
     my ($self, $fh, $pdf, %opts) = @_;
 
     return $self->SUPER::outobjdeep($fh, $pdf) if defined $opts{'passthru'};
@@ -171,16 +193,22 @@ sub outobjdeep {
     $self->{' de'}->{'W'} = $wx;
     my $ml;
 
-    foreach my $w (0..(scalar @{$self->data->{g2u}} - 1 )) {
-        if($self->subvec($w) && $notdefbefore==1) {
+    foreach my $w (0..(scalar @{$self->data->{g2u}} - 1 )) 
+    {
+        if($self->subvec($w) && $notdefbefore==1) 
+        {
             $notdefbefore=0;
             $ml=PDFArray();
             $wx->add_elements(PDFNum($w),$ml);
             $ml->add_elements(PDFNum($self->data->{wx}->[$w]));
-        } elsif($self->subvec($w) && $notdefbefore==0) {
+        } 
+        elsif($self->subvec($w) && $notdefbefore==0) 
+        {
             $notdefbefore=0;
             $ml->add_elements(PDFNum($self->data->{wx}->[$w]));
-        } else {
+        } 
+        else 
+        {
             $notdefbefore=1;
         }
         # optimization for cjk
@@ -212,6 +240,9 @@ alfred reibenschuh
 =head1 HISTORY
 
     $Log: TrueType.pm,v $
+    Revision 1.15  2005/10/20 21:04:57  fredo
+    added handling of optional kerning
+
     Revision 1.14  2005/10/01 22:30:16  fredo
     fixed font-naming race condition for multiple document updates
 
